@@ -1,8 +1,12 @@
 """Decorators module."""
+from functools import wraps
+
 from loguru import logger
 
-from ..config import DEFAULTS
+from ..bootstrap import _CLI
 
+
+DEFAULTS = _CLI().get_config()
 logger.add(DEFAULTS.logfile, format="{time} | {level} | {message}")
 
 
@@ -51,3 +55,16 @@ def log_test(fn):
         fn(*args, **kwargs)
 
     return _
+
+
+def weight(value: int):
+    """Add a function a weight attr."""
+    def attr_decorator(fn):
+        @wraps(fn)
+        def _(*args, **kwargs):
+            return fn(*args, **kwargs)
+
+        setattr(_, "weight", value)
+        return _
+
+    return attr_decorator
