@@ -3,10 +3,12 @@ from json import dumps
 from requests import request
 
 from ..decorators import when
-from ..config import DEFAULTS
+from ..bootstrap import _CLI
 from .base_request import BaseRequest
 
 
+DEFAULTS = _CLI().get_config()
+
 class Actions(BaseRequest):
     """Assertio Request object."""
 
@@ -19,6 +21,7 @@ class Actions(BaseRequest):
         self.response = request(
             self.method,
             f"{DEFAULTS.base_url}{self.endpoint}",
+            cookies=self.cookies,
             params=self.params,
             data=dumps(self.body),
             headers=self.headers,
